@@ -2,9 +2,13 @@
  * chvt.c - aeb - 940227 - Change virtual terminal
  */
 #include <sys/types.h>
+#include <sys/ioctl.h>
 #include <linux/vt.h>
 #include <stdio.h>
+#include <stdlib.h>
+#include <fcntl.h>
 
+int
 main(int argc, char *argv[]) {
     int fd, num;
 
