@@ -1,17 +1,22 @@
 /*
  * disalloc.c - aeb - 940501 - Disallocate virtual terminal(s)
  */
+#include <stdlib.h>
+#include <fcntl.h>
 #include <sys/types.h>
+#include <sys/ioctl.h>
 #include <linux/vt.h>
 #include <stdio.h>
 
 char *progname;
 
+void
 usage(){
     fprintf(stderr, "usage: %s [N1 N2 ...]\n", progname);
     exit(1);
 }
 
+int
 main(int argc, char *argv[]) {
     int fd, num, i;
 
