@@ -146,7 +146,6 @@ char valid_type(int t) {
 
 u_char maximum_val(int t) {
 	struct kbentry ke;
-	int old_value;
 	int i;
 
 	ke.kb_index = 0;
@@ -218,7 +217,7 @@ void dump_symbols(void) {
 		 synonyms[t].official_name);
 	printf("\nRecognized modifier names and their column numbers:\n");
 	for (t = 0; t < sizeof(modifiers)/sizeof(modifiers[0]); t++)
-	  printf("%s\t%d", modifiers[t].name, 1 << modifiers[t].bit);
+	  printf("%s\t\t%3d\n", modifiers[t].name, 1 << modifiers[t].bit);
 }
 
 void print_mod(int x) {
