@@ -165,11 +165,11 @@ static char *latin1_syms[] = {
 	"nobreakspace",
 	"exclamdown",
 	"cent",
-	"pound",
+	"sterling",
 	"currency",
 	"yen",
 	"brokenbar",
-	"paragraph",
+	"section",
 	"diaeresis",
 	"copyright",
 	"ordfeminine",
@@ -217,7 +217,7 @@ static char *latin1_syms[] = {
 	"Ocircumflex",
 	"Otilde",
 	"Odiaeresis",
-	"multiplication",
+	"multiply",
 	"Ooblique",
 	"Ugrave",
 	"Uacute",
@@ -711,7 +711,8 @@ static char *spec_syms[] = {
 	"Compose",
 	"SAK",
 	"Decr_Console",
-	"Incr_Console"
+	"Incr_Console",
+	"Spawn_Console"
 };
 
 static char *pad_syms[] = {
@@ -767,7 +768,46 @@ static char *cons_syms[] = {
 	"Console_21",
 	"Console_22",
 	"Console_23",
-	"Console_24"
+	"Console_24",
+	"Console_25",
+	"Console_26",
+	"Console_27",
+	"Console_28",
+	"Console_29",
+	"Console_30",
+	"Console_31",
+	"Console_32",
+	"Console_33",
+	"Console_34",
+	"Console_35",
+	"Console_36",
+	"Console_37",
+	"Console_38",
+	"Console_39",
+	"Console_40",
+	"Console_41",
+	"Console_42",
+	"Console_43",
+	"Console_44",
+	"Console_45",
+	"Console_46",
+	"Console_47",
+	"Console_48",
+	"Console_49",
+	"Console_50",
+	"Console_51",
+	"Console_52",
+	"Console_53",
+	"Console_54",
+	"Console_55",
+	"Console_56",
+	"Console_57",
+	"Console_58",
+	"Console_59",
+	"Console_60",
+	"Console_61",
+	"Console_62",
+	"Console_63"
 };
 
 static char *cur_syms[] = {
@@ -992,17 +1032,23 @@ synonyms[] = {
 	{ "End",		"Select" },
 	{ "PageUp",		"Prior" },
 	{ "PageDown",		"Next" },
-	{ "multiply",		"multiplication" },
-	{ "sterling",		"pound" },
-	{ "section",		"paragraph" },
+	{ "multiplication",	"multiply" },
+	{ "pound",		"sterling" },
+	{ "pilcrow",		"paragraph" },
+	{ "Oslash",		"Ooblique" },
 	{ "Shift_L",		"ShiftL" },
 	{ "Shift_R",		"ShiftR" },
 	{ "Control_L",		"CtrlL" },
 	{ "Control_R",		"CtrlR" },
+	{ "AltL",		"Alt" },
+	{ "AltR",		"AltGr" },
 	{ "Alt_L",		"Alt" },
 	{ "Alt_R",		"AltGr" },
 	{ "AltGr_L",		"Alt" },
 	{ "AltGr_R",		"AltGr" },
+	{ "AltLLock",		"Alt_Lock" },
+	{ "AltRLock",		"AltGr_Lock" },
+	{ "KeyboardSignal",	"Spawn_Console" },
 /* the names of the Greek letters are spelled differently
    in the iso-8859-7 and the Unicode standards */
 	{ "lambda",             "lamda" },
@@ -1010,7 +1056,10 @@ synonyms[] = {
 	{ "xi",                 "ksi" },
 	{ "Xi",                 "Ksi" },
 	{ "chi",                "khi" },
-	{ "Chi",                "Khi" }
+	{ "Chi",                "Khi" },
+/* diacriticals */
+	{ "tilde",		"asciitilde" },
+	{ "circumflex",		"asciicircum" },
 };
 
 const int syms_size = sizeof(syms) / sizeof(syms_entry);
