@@ -1,6 +1,6 @@
 /*
  * All data is in subdirectories of DATADIR, by default /usr/lib/kbd
- * The following three subdirectories are defined:
+ * The following four subdirectories are defined:
  */
 #define KEYMAPDIR "keytables"
 #define FONTDIR "consolefonts"
@@ -12,3 +12,6 @@
  */
 #define DEFMAP "defkeymap.map"
 #define KERNDIR "/usr/src/linux/drivers/char"
+
+extern FILE *findfile(char *fnam, char **dirpath, char **suffixes);
+extern char pathname[];
