@@ -17,11 +17,12 @@ usage(void)
 {
     fprintf(stderr, "\
 Usage:
-	setleds [-L] [-D] [-F] [[+|-][ num | caps | scroll ]]
+	setleds [-v] [-L] [-D] [-F] [[+|-][ num | caps | scroll ]]
 Thus,
 	setleds +caps -num
 will set CapsLock, clear NumLock and leave ScrollLock unchanged.
-The settings before and after the change (if any) are reported.
+The settings before and after the change (if any) are reported
+when the -v option is given or when no change is requested.
 Normally, setleds influences the vt flag settings
 (and these are usually reflected in the leds).
 With -L, setleds only sets the leds, and leaves the flags alone.
@@ -56,7 +57,7 @@ struct led {
 int
 main(argc,argv) int argc; char **argv;
 {
-    int optL = 0, optD = 0, optF = 0;
+    int optL = 0, optD = 0, optF = 0, verbose = 0;
     char oleds, nleds, oflags, nflags, odefflags, ndefflags;
     char nval, ndef, sign;
     char *ap;
@@ -83,6 +84,8 @@ main(argc,argv) int argc; char **argv;
 	  optD = 1;
 	else if (!strcmp("-F", argv[1]))
 	  optF = 1;
+	else if (!strcmp("-v", argv[1]))
+	  verbose = 1;
 	else
 	  break;
 	argc--;
@@ -101,6 +104,8 @@ main(argc,argv) int argc; char **argv;
 		exit(1);
 	    }
 	}
+
+	/* If nothing to do, report, even if not verbose */
 	if (!optD && !optL && !optF)
 	  optD = optL = optF = 1;
 	if (optD) {
@@ -148,17 +153,21 @@ main(argc,argv) int argc; char **argv;
 
     if (optD) {
 	ndefflags = (odefflags & ~ndef) | nval;
-	printf("Old default flags:    ");
-	report(odefflags);
-	printf("New default flags:    ");
-	report(ndefflags);
+	if (verbose) {
+	    printf("Old default flags:    ");
+	    report(odefflags);
+	    printf("New default flags:    ");
+	    report(ndefflags);
+	}
     }
     if (optF) {
 	nflags = ((oflags & ~ndef) | nval);
-	printf("Old flags:            ");
-	report(oflags & 07);
-	printf("New flags:            ");
-	report(nflags & 07);
+	if (verbose) {
+	    printf("Old flags:            ");
+	    report(oflags & 07);
+	    printf("New flags:            ");
+	    report(nflags & 07);
+	}
     }
     if (optD || optF) {
 	if (ioctl(0, KDSKBLED, (ndefflags << 4) | nflags)) {
@@ -167,15 +176,17 @@ main(argc,argv) int argc; char **argv;
 	}
     }
     if (optL) {
-	printf("Old leds:             ");
-	report(oleds);
 	nleds = (oleds & ~ndef) | nval;
+	if (verbose) {
+	    printf("Old leds:             ");
+	    report(oleds);
+	    printf("New leds:             ");
+	    report(nleds);
+	}
 	if (ioctl(0, KDSETLED, nleds)) {
 	    perror("KDSETLED");
 	    exit(1);
 	}
-	printf("New leds:             ");
-	report(nleds);
     }
     exit(0);
 }
