@@ -8,9 +8,9 @@
 #include <linux/keyboard.h>
 #include <sys/ioctl.h>
 
-#define VERSION "0.86"
+#define VERSION "0.90"
 
-int tmp;	/* for debuggin */
+int tmp;	/* for debugging */
 
 #define OPTION "medium raw"
 
@@ -19,7 +19,7 @@ int oldkbmode;
 struct termios old;
 
 /*
- * version 0.81 of showkeys would restore kbmode unconditially to XLATE,
+ * version 0.81 of showkey would restore kbmode unconditially to XLATE,
  * thus making the console unusable when it was called under X.
  */
 void get_mode(void) {
@@ -84,6 +84,7 @@ valid options are:
 	exit(1);
 }
 
+int
 main (int argc, char *argv[]) {
 	const char *short_opts = "hsk";
 	const struct option long_opts[] = {
